@@ -1,22 +1,15 @@
-# $Id: clicli.pm 461 2009-01-19 22:56:47Z pro $ $URL: svn://svn.setun.net/dcppp/trunk/lib/Net/DirectConnect/clicli.pm $
+#$Id: clicli.pm 472 2009-08-25 05:52:44Z pro $ $URL: svn://svn.setun.net/dcppp/trunk/lib/Net/DirectConnect/clicli.pm $
 package Net::DirectConnect::clicli;
 use Net::DirectConnect;
 use strict;
 no warnings qw(uninitialized);
-our $VERSION = ( split( ' ', '$Revision: 461 $' ) )[1];
+our $VERSION = ( split( ' ', '$Revision: 472 $' ) )[1];
 use base 'Net::DirectConnect';
 
 sub init {
   my $self = shift;
-  #print( "$self::init from ", join(':', caller), "\n");
-  #print "1.0: $self->{'Nick'} : ",@_,"\n";
-  #print "Sc0[$self->{'socket'}]\n";
   %$self = (
     %$self,
-    #    'Nick' => 'dcpppBot',
-    #	'Key'	=> 'zzz',
-    #	'Supports' => 'MiniSlots XmlBZList ADCGet TTHL TTHF GetZBlock ZLI',
-    #	'Supports' => 'XmlBZList',
     #http://www.dcpp.net/wiki/index.php/%24Supports
     'supports_avail' => [ qw(
         BZList
@@ -38,78 +31,40 @@ sub init {
     'MiniSlots' => 1,
     @_,
     'direction' => 'Download',
-    #	'Direction' => 'Upload', #rand here
-    #	'incomingclass' => 'dcppp::clicli',
+    #'Direction' => 'Upload', #rand here
     'reconnects' => 0,
   );
   $self->{'auto_connect'} = 1 if !$self->{'incoming'} and !defined $self->{'auto_connect'};
   $self->baseinit();
-  #print "1: $self->{'Nick'}\n";
-  #print "Sc1[$self->{'socket'}]\n";
-  #print "CLICLI init [$self->{'number'}]\n";
-  #    ($self->{'peerport'}, $self->{'peerip'}) = unpack_sockaddr_in( getpeername( $self->{'socket'} ) ) if $self->{'socket'};
-  #    $self->{'peerip'}  = inet_ntoa($self->{'peerip'}) if $self->{'peerip'};
   $self->get_peer_addr();
-  #     $self->log('info', "[$self->{'number'}] Incoming client $self->{'peerip'}") if $self->{'peerip'};
+  #$self->log('info', "[$self->{'number'}] Incoming client $self->{'peerip'}") if $self->{'peerip'};
   $self->log( 'info', "Incoming client $self->{'host'}:$self->{'port'} via ", ref $self ) if $self->{'incoming'};
-  #print("{{  $self->{'NickList'} }}");
-  #print("[$_]")for sort keys %{$self->{'NickList'}};
-  #print " clicli init clients:{", keys %{$self->{'clients'}}, "}\n";
-  #print "parse init\n";
-  #    %{$self->{'parse'}} = (
-$self->{'parse'} = undef if $self->{'parse'} and  !keys %{$self->{'parse'}};
+  $self->{'parse'} = undef if $self->{'parse'} and !keys %{ $self->{'parse'} };
   $self->{'parse'} ||= {
     'Lock' => sub {
-      #print "CLICLI lock parse\n";
       if ( $self->{'incoming'} ) {
         $self->{'sendbuf'} = 1;
         $self->cmd('MyNick');
-        #          $self->{'sendbuf'} = 0;
+        #$self->{'sendbuf'} = 0;
         $self->cmd('Lock');
-        #	  $self->recv();
-        #          $self->{'sendbuf'} = 1;
+        #$self->{'sendbuf'} = 1;
         $self->cmd('Supports');
-        #          $self->{'Direction'} = 'Download';
         $self->cmd('Direction');
         $self->{'sendbuf'} = 0;
-        #          $_[0] =~ /(\S+)/;
-        #          $_[0] =~ /^(.+) Pk=/i;
-        #          $_[0] =~ /^(.+?)( Pk=.+)?$/i;
         $_[0] =~ /^(.+?)(\s+Pk=.+)?\s*$/is;
         $self->cmd( 'Key', Net::DirectConnect::lock2key($1) );
-        #	  $self->cmd('Key', Net::DirectConnect::lock2key($_[0]));
       } else {
         $_[0] =~ /^(.+?)(\s+Pk=.+)?\s*$/is;
-        #	  $self->cmd('Key', Net::DirectConnect::lock2key($1));
         $self->{'key'} = Net::DirectConnect::lock2key($1);
-        #         $self->{'sendbuf'} = 1;
-        #         $self->cmd('MyNick');
-        #	  $self->{'sendbuf'} = 0;
-        #	  $self->cmd('Lock');
       }
     },
-    #      'Supports' => sub { },
     'Direction' => sub {
-      #$self->cmd('selectfile') if $self->{'Direction'} eq 'Download';
       if   ( $_[0] eq 'Download' ) { $self->{'direction'} = 'Upload'; }
       else                         { $self->{'direction'} = 'Download'; }
     },
     'Key' => sub {
-      if ( $self->{'incoming'} ) {
-        #  	  $self->cmd('Supports');
-        #          $self->{'Direction'} = 'Download';
-        #  	  $self->cmd('Direction');
-        #print " CL $self->{'number'} [nick:$_] " for keys %{$self->{'want'}};
-
-=c
-          for(keys %{$self->{'want'}->{$self->{'peernick'}}}) {
-             ($self->{'filename'}, $self->{'fileas'}) =  
-             ($_, $self->{'want'}->{$self->{'peernick'}}{$_});
-             last;
-          }
-=cut
-
-      } else {
+      if ( $self->{'incoming'} ) { }
+      else {
         $self->{'sendbuf'} = 1;
         $self->cmd('Supports');
         $self->cmd('Direction');
@@ -129,32 +84,17 @@ $self->{'parse'} = undef if $self->{'parse'} and  !keys %{$self->{'parse'}};
     },
     'MyNick' => sub {
       $self->log( 'info', "peer is [", ( $self->{'peernick'} = $_[0] ), "]" );
-      #         $self->{'NickList'}->{$self->{'peernick'}}{'ip'} = $self->{'peerip'};
-      $self->{'NickList'}->{ $self->{'peernick'} }{'ip'} = $self->{'host'};
-      #         $self->{'NickList'}->{$self->{'peernick'}}{'port'} = ($self->{'peerport'} or $self->{'port'});
+      $self->{'NickList'}->{ $self->{'peernick'} }{'ip'}   = $self->{'host'};
       $self->{'NickList'}->{ $self->{'peernick'} }{'port'} = $self->{'port'};
-      #         $self->{'IpList'}->{$self->{'peerip'}} = \%{ $self->{'NickList'}->{$self->{'peernick'} } };
-      #         $self->{'IpList'}->{$self->{'peerip'}}->{'port'} = $self->{'PortList'}->{$self->{'peerip'}};
-      $self->{'IpList'}->{ $self->{'host'} } = \%{ $self->{'NickList'}->{ $self->{'peernick'} } };
-      $self->{'IpList'}->{ $self->{'host'} }->{'port'} = $self->{'PortList'}->{ $self->{'host'} };
+      $self->{'IpList'}->{ $self->{'host'} }               = \%{ $self->{'NickList'}->{ $self->{'peernick'} } };
+      $self->{'IpList'}->{ $self->{'host'} }->{'port'}     = $self->{'PortList'}->{ $self->{'host'} };
       $self->handler( 'user_ip', $self->{'peernick'}, $self->{'host'}, $self->{'port'} );
-      #$self->log('dev', "[$self->{'number'}] peer port is [ip:$self->{'host'} pl",
-      # $self->{'PortList'}->{$self->{'host'}},
-      # 'nl',$self->{'NickList'}->{$self->{'peernick'}}{'port'},
-      # 'port',$self->{'port'},"]");
-      if ( keys %{ $self->{'want'}->{ $self->{'peernick'} } } ) {
-        #print ("we want to download ",keys %{$self->{'want'}->{$self->{'peernick'}}}, " files\n");
-        $self->{'direction'} = 'Download';
-      } else {
-        $self->{'direction'} = 'Upload';
-        #print ("we dont want to download \n");
-      }
+      if   ( keys %{ $self->{'want'}->{ $self->{'peernick'} } } ) { $self->{'direction'} = 'Download'; }
+      else                                                        { $self->{'direction'} = 'Upload'; }
     },
     'FileLength' => sub {
       $self->{'filetotal'} = $_[0];
       return if $self->openfile();
-      #        open($self->{'filehandle'}, '>', ($self->{'fileas'} or $self->{'filename'})) or return;
-      #        binmode($self->{'filehandle'});
       $self->cmd('Send');
     },
     'ADCSND' => sub {
@@ -162,15 +102,11 @@ $self->{'parse'} = undef if $self->{'parse'} and  !keys %{$self->{'parse'}};
       $_[0] =~ /(\d+?)$/is;
       $self->{'filetotal'} = $1;
       return if $self->openfile();
-      #        open($self->{'filehandle'}, '>', ($self->{'fileas'} or $self->{'filename'})) or return;
-      #        binmode($self->{'filehandle'});
     },
     'CSND' => sub {
       $_[0] =~ /^file\s+\S+\s+(\d+)\s(\d+)$/is;
       $self->{'filetotal'} = $2;
       return if $self->openfile();
-      #        open($self->{'filehandle'}, '>', ($self->{'fileas'} or $self->{'filename'})) or return;
-      #        binmode($self->{'filehandle'});
     },
     'Supports' => sub {
       $self->supports_parse( $_[0], $self->{'NickList'}->{ $self->{'peernick'} } );
@@ -179,16 +115,10 @@ $self->{'parse'} = undef if $self->{'parse'} and  !keys %{$self->{'parse'}};
       $self->disconnect();
       }
   };
-  $self->log ( 'dev',"cmd init1 [$self]", ); #Dumper $self
-  $self->log ( 'dev',"cmd init2 [$self] z ( $self->{'cmd'} )", ); #Dumper $self->{'cmd'}
-  #    %{$self->{'cmd'}} = {
-
-  $self->log ( 'dev', "del empty cmd", ), #Dumper $self
-$self->{'cmd'} = undef if $self->{'cmd'} and  !keys %{$self->{'cmd'}};
-
+  #$self->log ( 'dev', "del empty cmd", ),
+  $self->{'cmd'} = undef if $self->{'cmd'} and !keys %{ $self->{'cmd'} };
   $self->{'cmd'} ||= {
     'connect_aft' => sub {
-      #      $self->connect() && return;
       $self->{'sendbuf'} = 1;
       $self->cmd('MyNick');
       $self->{'sendbuf'} = 0;
@@ -212,9 +142,7 @@ $self->{'cmd'} = undef if $self->{'cmd'} and  !keys %{$self->{'cmd'}};
           $self->{'fileext'}  = '.DcLst';
           $self->{'filename'} = 'MyList' . $self->{'fileext'};
         }
-        #$self->log('dev', "fas was", $self->{'fileas'});
         $self->{'fileas'} .= $self->{'fileext'} if $self->{'fileas'};
-        #$self->log('dev', "fas now", $self->{'fileas'});
       }
     },
     'MyNick' => sub {
@@ -223,11 +151,11 @@ $self->{'cmd'} = undef if $self->{'cmd'} and  !keys %{$self->{'cmd'}};
     'Lock' => sub {
       $self->sendcmd( 'Lock', $self->{'lock'} );
     },
-    #      'Supports'	=> sub { $self->sendcmd('Supports', $self->{'Supports'}); },
-    'Supports' => sub { $self->sendcmd( 'Supports', ( $self->supports() or return ) ); },
+    'Supports' => sub {
+      $self->sendcmd( 'Supports', ( $self->supports() or return ) );
+    },
     'Direction' => sub {
       $self->sendcmd( 'Direction', $self->{'direction'}, int( rand(0x7FFF) ) );
-      #$self->{'want'}->{$self->{'peernick'}}
     },
     'Key' => sub {
       my $self = shift if ref $_[0];
@@ -248,7 +176,5 @@ $self->{'cmd'} = undef if $self->{'cmd'} and  !keys %{$self->{'cmd'}};
       $self->sendcmd( 'ADCGET', $self->{'adcget'} );
     },
   };
-  #print " clicli aftinit clients:{", keys %{$self->{'clients'}}, "}\n";
-  $self->log ( "init end");
 }
 1;
